import 'package:flutter/material.dart';

import 'package:intl/intl.dart';
import 'package:provider/provider.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

import '../senior_calendar.dart';
import '../../../theme/senior_theme_data.dart';
import '../../../repositories/theme_repository.dart';

class SeniorWeekdayRow extends StatelessWidget {
  /// Creates the line with the days of the week on the calendar.
  /// The [showWeekdays] and [localeDate] parameters are required.
  SeniorWeekdayRow(
    this.firstDayOfWeek,
    this.customWeekdayBuilder, {
    required this.showWeekdays,
    required this.localeDate,
    this.style,
  });

  final WeekdayBuilder? customWeekdayBuilder;
  final bool showWeekdays;
  final DateFormat localeDate;
  final int firstDayOfWeek;
  final SeniorCalendarStyle? style;

  Widget _weekdayContainer({
    required int weekday,
    required String weekDayName,
    required SeniorThemeData theme,
  }) {
    final customWeekdayBuilder = this.customWeekdayBuilder;

    final weekdayTextColor = style?.weekDaysColor ??
        theme.calendarTheme?.style?.weekDaysColor ??
        SeniorColors.neutralColor700;

    return customWeekdayBuilder != null
        ? customWeekdayBuilder(weekday, weekDayName)
        : Expanded(
            child: Container(
              margin: const EdgeInsets.only(bottom: SeniorSpacing.normal / 2),
              child: Center(
                child: Text(
                  weekDayName,
                  semanticsLabel: weekDayName,
                  style: SeniorTypography.label(color: weekdayTextColor),
                ),
              ),
            ),
          );
  }

  List<Widget> _renderWeekDays({
    required SeniorThemeData theme,
  }) {
    final List<Widget> list = [];

    // because of number of days in a week is 7, so it would be easier to count it til 7.
    // ignore: avoid_multiple_declarations_per_line
    for (var i = firstDayOfWeek, count = 0; count < 7; i = (i + 1) % 7, count++) {
      list.add(
        _weekdayContainer(
          weekday: count,
          weekDayName: localeDate.dateSymbols.SHORTWEEKDAYS[i].toUpperCase(),
          theme: theme,
        ),
      );
    }

    return list;
  }

  @override
  Widget build(BuildContext context) {
    final theme = Provider.of<ThemeRepository>(context).theme;

    return showWeekdays
        ? Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: _renderWeekDays(
              theme: theme,
            ),
          )
        : const SizedBox();
  }
}
